# Create a Datacube for scaling geospatial analyses

See the examples directory and DataCube class for more information on the API.  

Modified from a [tutorial](https://earthmover.io/blog/serverless-datacube-pipeline) by Ryan Abernathy and the Earthmover team.

## Running
This package is intended to be distributed via pip, or with the attached Dockerfile.  It may need some updating to handle volume mounts for data, which can be done in the Makefile.  And I had some trouble publishing to PyPI from my local Mac M1, but it has been running fine on Linux.  

